# Generated by roxygen2: do not edit by hand

export(bang)
export(base_match)
export(base_when)
export(bracket)
export(dollar)
export(et)
export(not)
export(p_cor)
export(p_glm)
export(p_lm)
export(p_t.test)
export(p_table)
export(p_wilcox.test)
