#' National Health and Nutrition Examination Survey data
#'
#' A subset of data from the National Health and Nutrition Examination Survey
#'
#' @format ## `nhanes`
#' A data frame with 8,153 rows and 3 columns:
#' \describe{
#'   \item{seqn}{a unique identifier}
#'   \item{riagendr}{gender}
#'   \item{ridageyr}{age}
#'   \item{dmqmiliz}{military status}
#'   \item{dmdborn4}{country of birth}
#'   \item{lbxtc}{total cholesterol}
#'   \item{bpxosy1}{systolic blood pressure}
#'   \item{bpxosy2}{systolic blood pressure}
#'   \item{bpxodi1}{diastolic blood pressure}
#'   \item{bpxodi2}{diastolic blood pressure}
#'   \item{mcq010}{asthma}
#'   \item{smq020}{smoking status}
#' }
#' @source <https://wwwn.cdc.gov/nchs/nhanes/continuousnhanes/default.aspx?Cycle=2021-2023>
"nhanes"